@@ -482,13 +482,13 @@ GtkWidget* create_mainwin(Note *note) {
 	gtk_box_pack_start(GTK_BOX (vbox1), scrolledwindow1, TRUE, TRUE, 0);
 
 	/* TEXT VIEW */
-#ifdef HILDON_HAS_APP_MENU
-	textview = hildon_text_view_new();
-	buffer = hildon_text_view_get_buffer(HILDON_TEXT_VIEW(textview));
-#else
+//#ifdef HILDON_HAS_APP_MENU
+//	textview = hildon_text_view_new();
+//	buffer = hildon_text_view_get_buffer(HILDON_TEXT_VIEW(textview));
+//#else
 	textview = gtk_text_view_new();
 	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
-#endif
+//#endif
 	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(textview), GTK_WRAP_WORD);
 	gtk_widget_show(textview);
 	gtk_container_add(GTK_CONTAINER (scrolledwindow1), textview);
